package com.lanren.huhu.partner.manager;

import com.lanren.huhu.partner.domain.PartnerAccount;
import com.lanren.huhu.partner.result.Result;
import com.lanren.huhu.partner.service.PartnerAccountService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * @author houseme
 * @date 2019-06-26 10:56
 * @Project partner
 * @Package com.lanren.huhu.partner.manager
 * @File: PartnerAccountManager
 */
@Component
public class PartnerAccountManager {
    private static Logger logger = LoggerFactory.getLogger(PartnerAccountManager.class);

    @Autowired
    private PartnerAccountService partnerAccountService;

    /***
     * 获取合伙人账户信息
     * @param userId
     * @return
     */
    public Result<PartnerAccount> findByUserId(Integer userId) {
        Result<PartnerAccount> result = new Result<>();
        if (logger.isDebugEnabled()) {
            logger.info("PartnerAccountManager findByUserId userId:{},time:{}", userId, LocalDateTime.now());
        }
        result.setData(partnerAccountService.getOneByUserId(userId));
        return result;
    }

    public Result<Map<String, Integer>> getPartnerLevel(Integer userId) {
        if (logger.isDebugEnabled()) {
            logger.info("PartnerAccountManager getPartnerLevel userId:{},time:{}", userId, LocalDateTime.now());
        }
        Result<Map<String, Integer>> result = new Result<>();
        Map<String, Integer> map = new HashMap<String, Integer>();
        int partnerLevel;
        PartnerAccount partnerAccount = partnerAccountService.getOneByUserId(userId);
        if (null != partnerAccount) {
            if (partnerAccount.getIsSuperPartner() ==1) {
                partnerLevel = 30;
            } else {
                partnerLevel = partnerAccount.getPartnerLevel();
            }
        } else {
            partnerLevel = -1;
            result.setCode(601);
        }
        map.put("level", partnerLevel);
        result.setData(map);
        return result;
    }
}
